import { GlobalWorkerOptions, version, getDocument } from 'pdfjs-dist';
import Konva from 'konva';
import { html, internalProperty, property, customElement, LitElement } from 'lit-element';

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __decorate(decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
}

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

GlobalWorkerOptions.workerSrc = `//cdnjs.cloudflare.com/ajax/libs/pdf.js/${version}/pdf.worker.js`;
const getImageFromPage = (_document, pageNumber) => new Promise((resolve, reject) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const page = yield _document.getPage(pageNumber);
        const canvas = document.createElement('canvas');
        const context = canvas.getContext('2d');
        const viewport = page.getViewport({ scale: 1 });
        canvas.height = viewport.height;
        canvas.width = viewport.width;
        const renderContext = {
            canvasContext: context,
            viewport: viewport,
        };
        page.render(renderContext).promise.then(() => {
            resolve(canvas.toDataURL());
        });
    }
    catch (error) {
        reject(null);
    }
}));
const getImagesFromPDF = (file) => new Promise((resolve, reject) => {
    getDocument(file).promise.then((document) => {
        Promise.all(Array.from(Array(document.numPages).keys()).map((index) => getImageFromPage(document, index + 1)))
            .then((images) => {
            resolve(images);
        })
            .catch(() => {
            reject([]);
        });
    });
});

var KONVA_REFS;
(function (KONVA_REFS) {
    KONVA_REFS["imageLayer"] = "image-layer";
    KONVA_REFS["shapesLayer"] = "shapes-layer";
    KONVA_REFS["imageShape"] = "image-shape";
    KONVA_REFS["shape"] = "shape";
})(KONVA_REFS || (KONVA_REFS = {}));
const DEFAULT_OPTIONS = {
    backgroundColor: 'black',
    shapeConfig: {
        stroke: 'red',
        strokeWidth: 3,
        listening: true,
    },
    zoom: {
        modifier: 1.2,
        max: 10,
        defaultZoom: 1,
    },
};

const handleStageZoom = (event, stage, imageBoundingBox, options = DEFAULT_OPTIONS.zoom) => {
    const { x, y, scale } = imageBoundingBox;
    event.evt.preventDefault();
    const oldScale = stage.scaleX();
    const stageX = stage.x();
    const stageY = stage.y();
    const { x: pointerX, y: pointerY } = stage.getPointerPosition();
    const mousePointTo = {
        x: (pointerX - stageX) / oldScale,
        y: (pointerY - stageY) / oldScale,
    };
    const { max, modifier, defaultZoom } = options;
    const newScale = event.evt.deltaY < 0 ? oldScale * modifier : oldScale / modifier;
    if (newScale > max) {
        return;
    }
    if (newScale / scale <= defaultZoom) {
        stage.draggable(false);
        stage.scale({ x: scale, y: scale });
        stage.position({ x, y });
    }
    else {
        stage.draggable(true);
        stage.scale({ x: newScale, y: newScale });
        const newPos = {
            x: pointerX - mousePointTo.x * newScale,
            y: pointerY - mousePointTo.y * newScale,
        };
        stage.position(newPos);
    }
    stage.batchDraw();
};
const handleLensZoom = (stage, imageBoundingBox, pointerPosition, zoomLevel) => {
    const { height, width, scale } = imageBoundingBox;
    const { x: _x, y: _y } = pointerPosition;
    const pointerX = (_x * width) / scale;
    const pointerY = (_y * height) / scale;
    const newScale = zoomLevel;
    stage.scale({ x: newScale, y: newScale });
    const newPos = {
        x: -pointerX * newScale + stage.width() / 2,
        y: -pointerY * newScale + stage.height() / 2,
    };
    stage.position(newPos);
    stage.batchDraw();
};
const getMousePosition = (stage, imageBoundingBox) => {
    const { x: pointerX, y: pointerY } = stage.getPointerPosition();
    const oldScale = stage.scaleX();
    const stageX = stage.x();
    const stageY = stage.y();
    return {
        x: ((pointerX - stageX) * imageBoundingBox.scale) /
            (oldScale * imageBoundingBox.width),
        y: ((pointerY - stageY) * imageBoundingBox.scale) /
            (oldScale * imageBoundingBox.height),
    };
};

const getImageBoundingBox = ({ clientWidth, clientHeight }, imageObj) => {
    const imageAspectRatio = imageObj.width / imageObj.height;
    const canvasAspectRatio = clientWidth / clientHeight;
    let renderableHeight, renderableWidth, xStart, yStart;
    // Happy path - keep aspect ratio
    xStart = 0;
    yStart = 0;
    renderableHeight = clientHeight;
    renderableWidth = clientWidth;
    // If image's aspect ratio is less than canvas's we fit on height
    // and place the image centrally along width
    if (imageAspectRatio < canvasAspectRatio) {
        renderableWidth = imageObj.width * (renderableHeight / imageObj.height);
        xStart = Math.round((clientWidth - renderableWidth) / 2);
    }
    // If image's aspect ratio is greater than canvas's we fit on width
    // and place the image centrally along height
    else if (imageAspectRatio > canvasAspectRatio) {
        renderableHeight = imageObj.height * (renderableWidth / imageObj.width);
        yStart = Math.round((clientHeight - renderableHeight) / 2);
    }
    return {
        scale: Number(Number(renderableWidth / imageObj.width).toFixed(3)),
        x: xStart,
        y: yStart,
        width: Math.round(renderableWidth),
        height: Math.round(renderableHeight),
    };
};
const mapPolygonToImage = (polygon) => {
    const stage = polygon.getStage().clone({});
    const polygons = stage.find(`.${KONVA_REFS.shape}`);
    const polygonId = polygon.id();
    polygons.forEach((_polygon) => {
        if (_polygon.id() !== polygonId)
            _polygon.hide();
    });
    const clientRect = polygon.getClientRect();
    return new Promise((callback) => {
        const crop = polygon.getAttr('crop');
        if (crop) {
            callback(crop);
        }
        stage.toDataURL(Object.assign(Object.assign({}, clientRect), { quality: 1, pixelRatio: 3, callback }));
    });
};

const mapShapesToPolygons = (stage, shapes, imageBoundingBox, { onClick, onMouseEnter, onMouseLeave }, options = DEFAULT_OPTIONS) => {
    clearDeprecatedShapes(stage, shapes);
    return shapes.reduce((accumulator, shape) => {
        let polygon = stage.findOne(`#${shape.id}`);
        let shapeConfig = options.shapeConfig;
        if (shape.config) {
            shapeConfig = Object.assign(Object.assign({}, shapeConfig), shape.config);
        }
        if (polygon) {
            polygon.setAttrs(Object.assign(Object.assign(Object.assign(Object.assign({}, polygon.getAttrs()), { points: mapCoordinatesToPoints(shape.coordinates, imageBoundingBox) }), shapeConfig), { shape }));
            return accumulator;
        }
        polygon = new Konva.Line(Object.assign(Object.assign({ id: shape.id, name: KONVA_REFS.shape, points: mapCoordinatesToPoints(shape.coordinates, imageBoundingBox), closed: true }, shapeConfig), { shape }));
        const shapesLayer = stage.findOne(`#${KONVA_REFS.shapesLayer}`);
        polygon.on('mousedown', (event) => __awaiter(void 0, void 0, void 0, function* () {
            event.cancelBubble = true;
            stage.container().style.cursor = 'move';
            if (onClick) {
                const shape = yield mapPolygonToShape(polygon);
                onClick(shape);
            }
        }));
        polygon.on('mouseup', () => __awaiter(void 0, void 0, void 0, function* () {
            stage.container().style.cursor = 'pointer';
        }));
        polygon.on('mouseenter', function (event) {
            return __awaiter(this, void 0, void 0, function* () {
                shapesLayer && shapesLayer.batchDraw();
                event.cancelBubble = true;
                stage.container().style.cursor = 'pointer';
                if (onMouseEnter) {
                    const shape = yield mapPolygonToShape(polygon);
                    onMouseEnter(shape);
                }
            });
        });
        polygon.on('mouseleave', function (event) {
            return __awaiter(this, void 0, void 0, function* () {
                shapesLayer && shapesLayer.batchDraw();
                event.cancelBubble = true;
                stage.container().style.cursor = 'default';
                if (onMouseLeave) {
                    const shape = yield mapPolygonToShape(polygon);
                    onMouseLeave(shape);
                }
            });
        });
        accumulator.push(polygon);
        return accumulator;
    }, []);
};
const clearDeprecatedShapes = (stage, shapes) => {
    const polygons = stage.find(`.${KONVA_REFS.shape}`) || [];
    polygons.forEach((polygon) => {
        if (shapes.every((shape) => shape.id !== polygon.id())) {
            polygon.destroy();
        }
    });
};
const scalePointToImage = (point, imageBoundingBox) => {
    const { width, height, scale } = imageBoundingBox;
    return {
        x: (point.x * width) / scale,
        y: (point.y * height) / scale,
    };
};
const mapCoordinatesToPoints = (coordinates, imageBoundingBox) => coordinates.reduce((accumulator, element) => {
    const { x, y } = scalePointToImage({ x: element[0], y: element[1] }, imageBoundingBox);
    accumulator = accumulator.concat([x, y]);
    return accumulator;
}, []);
const mapPolygonToShape = (polygon) => __awaiter(void 0, void 0, void 0, function* () {
    try {
        const crop = yield mapPolygonToImage(polygon);
        polygon.setAttr('crop', crop);
        const shape = polygon.getAttr('shape');
        return Object.assign(Object.assign({}, shape), { crop });
    }
    catch (error) {
        console.error(error);
    }
});

// @ts-nocheck
const rotateImage = (file, degrees) => {
    let orientation = 1;
    switch (degrees) {
        case 0:
            orientation = 1;
            break;
        case 90:
            orientation = 6;
            break;
        case 180:
            orientation = 3;
            break;
        case 270:
            orientation = 8;
            break;
    }
    return applyRotation(file, orientation);
};
const applyRotation = (file, orientation) => new Promise((resolve) => {
    const image = new Image();
    image.onload = () => {
        // Create canvas (off screen) to render image and apply transformations
        const canvas = document.createElement('canvas');
        const context = canvas.getContext('2d', { alpha: false });
        const { width, height } = image;
        const [outputWidth, outputHeight] = orientation > 4 && orientation < 9 ? [height, width] : [width, height];
        // Using a square canvas on max(width, height) to rotate rectangular images
        const wh = Math.max(width, height);
        canvas.width = wh;
        canvas.height = wh;
        // output image can be aligned to the right or bottom
        let rightAligned = false;
        let bottomAligned = false;
        switch (orientation) {
            case 2:
                context.transform(-1, 0, 0, 1, wh, 0);
                rightAligned = true;
                break;
            case 3:
                context.transform(-1, 0, 0, -1, wh, wh);
                rightAligned = true;
                bottomAligned = true;
                break;
            case 4:
                context.transform(1, 0, 0, -1, 0, wh);
                bottomAligned = true;
                break;
            case 5:
                context.transform(0, 1, 1, 0, 0, 0);
                break;
            case 6:
                context.transform(0, 1, -1, 0, wh, 0);
                rightAligned = true;
                break;
            case 7:
                context.transform(0, -1, -1, 0, wh, wh);
                rightAligned = true;
                bottomAligned = true;
                break;
            case 8:
                context.transform(0, -1, 1, 0, 0, wh);
                bottomAligned = true;
                break;
        }
        // draw image now that transform matrix is set
        context.drawImage(image, 0, 0, width, height);
        // transfer image to new canvas with correct dimensions
        const outputCanvas = document.createElement('canvas');
        outputCanvas.width = outputWidth;
        outputCanvas.height = outputHeight;
        const outputContext = outputCanvas.getContext('2d', { alpha: false });
        const sx = rightAligned ? canvas.width - outputCanvas.width : 0;
        const sy = bottomAligned ? canvas.height - outputCanvas.height : 0;
        outputContext.drawImage(canvas, sx, sy, outputCanvas.width, outputCanvas.height, 0, 0, outputCanvas.width, outputCanvas.height);
        // export image data
        resolve(outputCanvas.toDataURL('image/jpeg'));
    };
    image.src = file;
});

const containerStyle = (background = 'black') => html `
  <style>
    :host {
      display: flex;
      height: 500px;
      width: 500px;
    }
    #container {
      height: 100%;
      width: 100%;
      background: ${background};
    }
  </style>
`;
const LensStyle = (background = 'black') => html `
  <style>
    :host {
      display: flex;
      height: 200px;
      width: 200px;
    }
    #container {
      height: 100%;
      width: 100%;
      background: ${background};
    }
    .wrapper {
      position: relative;
      height: 100%;
      width: 100%;
      background: black;
    }
    .icon {
      position: absolute;
      width: 30px;
      height: 30px;
      z-index: 2;
      top: 50%;
      left: 50%;
      transform: translate(-50%; -50%);
    }
  </style>
`;

let AnnotationViewer = class AnnotationViewer extends LitElement {
    constructor() {
        super();
        this.onShapeClick = (shape) => {
            const event = new CustomEvent('on-shape-click', {
                detail: { shape },
                bubbles: true,
                composed: true,
            });
            this.dispatchEvent(event);
        };
        this.onShapeMouseEnter = (shape) => {
            const event = new CustomEvent('on-shape-mouse-enter', {
                detail: { shape },
                bubbles: true,
                composed: true,
            });
            this.dispatchEvent(event);
        };
        this.onPointerMove = (pointerPosition) => {
            const event = new CustomEvent('on-pointer-move', {
                detail: { pointerPosition },
                bubbles: true,
                composed: true,
            });
            this.dispatchEvent(event);
        };
        this.onShapeMouseLeave = (shape) => {
            const event = new CustomEvent('on-shape-mouse-leave', {
                detail: { shape },
                bubbles: true,
                composed: true,
            });
            this.dispatchEvent(event);
        };
        this.onMouseMove = () => {
            if (!this.imageBoundingBox) {
                return;
            }
            const mousePointTo = getMousePosition(this.stage, this.imageBoundingBox);
            this.onPointerMove(mousePointTo);
        };
        this.resizeCanvas = () => {
            this.imageBoundingBox = getImageBoundingBox(this.container, this.imageObject);
            this.resizeStage();
            const { x, y, width, height, scale } = this.imageBoundingBox;
            this.stage.scale({
                x: scale,
                y: scale,
            });
            this.stage.position({ x, y });
            this.imageShape.width(width / scale);
            this.imageShape.height(height / scale);
            this.imageLayer.batchDraw();
            this.loadShapes();
        };
        this.resizeStage = () => {
            this.stage.width(this.container.clientWidth);
            this.stage.height(this.container.clientHeight);
        };
        this.loadImage = () => {
            this.imageObject.onload = () => {
                this.imageShape.image(this.imageObject);
                this.imageLayer.batchDraw();
                this.resizeCanvas();
            };
            if (this.orientation) {
                rotateImage(this.image, this.orientation).then((image) => {
                    this.imageObject.src = image;
                });
            }
            else {
                this.imageObject.src = this.image;
            }
        };
        this.loadShapes = () => {
            if (!this.imageBoundingBox) {
                return;
            }
            const polygons = mapShapesToPolygons(this.stage, this.shapes, this.imageBoundingBox, {
                onClick: this.onShapeClick,
                onMouseEnter: this.onShapeMouseEnter,
                onMouseLeave: this.onShapeMouseLeave,
            }, this.options);
            if (polygons.length) {
                this.shapesLayer.add(...polygons);
            }
            this.shapesLayer.batchDraw();
        };
        this.onZoom = (event) => {
            handleStageZoom(event, this.stage, this.imageBoundingBox, this.options.zoom);
        };
        this._image = '';
        this._options = DEFAULT_OPTIONS;
        this._shapes = [];
        this._orientation = 0;
        this.stage = null;
        this.imageBoundingBox = null;
        this.imageLayer = new Konva.Layer({ id: KONVA_REFS.imageLayer });
        this.shapesLayer = new Konva.Layer({ id: KONVA_REFS.shapesLayer });
        this.imageObject = new Image();
        this.imageShape = new Konva.Image({
            image: this.imageObject,
        });
    }
    get shapes() {
        return this._shapes;
    }
    set shapes(value) {
        this._shapes = value;
        this.loadShapes();
    }
    get image() {
        return this._image;
    }
    set image(value) {
        this._image = value;
        this.loadImage();
    }
    get orientation() {
        return this._orientation;
    }
    set orientation(value) {
        this._orientation = value;
        this.loadImage();
    }
    get options() {
        return this._options;
    }
    set options(value) {
        this._options = Object.assign(Object.assign({}, this._options), value);
    }
    firstUpdated() {
        this.container = this.shadowRoot.getElementById('container');
        this.stage = new Konva.Stage({
            // @ts-ignore
            container: this.container,
            width: this.container.clientWidth,
            height: this.container.clientHeight,
        });
        this.imageLayer.add(this.imageShape);
        // @ts-ignore
        this.stage.add(this.imageLayer, this.shapesLayer);
        this.stage.on('wheel', this.onZoom);
        this.stage.on('mousemove', this.onMouseMove);
    }
    connectedCallback() {
        super.connectedCallback();
        window.addEventListener('resize', this.resizeCanvas);
    }
    disconnectedCallback() {
        window.removeEventListener('resize', this.resizeCanvas);
        super.disconnectedCallback();
    }
    render() {
        return html `${containerStyle(this.options.backgroundColor)}
      <div id="container"></div>`;
    }
};
__decorate([
    internalProperty()
], AnnotationViewer.prototype, "imageBoundingBox", void 0);
__decorate([
    property({ type: Array })
], AnnotationViewer.prototype, "shapes", null);
__decorate([
    property({ type: String })
], AnnotationViewer.prototype, "image", null);
__decorate([
    property({ type: Number })
], AnnotationViewer.prototype, "orientation", null);
__decorate([
    property({ type: Object })
], AnnotationViewer.prototype, "options", null);
AnnotationViewer = __decorate([
    customElement('annotation-viewer')
], AnnotationViewer);

var targetIcon = "data:image/svg+xml,%3Csvg%20id%3D%22regular%22%20enable-background%3D%22new%200%200%2024%2024%22%20height%3D%22512%22%20viewBox%3D%220%200%2024%2024%22%20width%3D%22512%22%20xmlns%3D%22http%3A%2F%2Fwww.w3.org%2F2000%2Fsvg%22%3E%3Cpath%20d%3D%22m12%2022c-5.514%200-10-4.486-10-10s4.486-10%2010-10%2010%204.486%2010%2010-4.486%2010-10%2010zm0-18.5c-4.687%200-8.5%203.813-8.5%208.5s3.813%208.5%208.5%208.5%208.5-3.813%208.5-8.5-3.813-8.5-8.5-8.5z%22%2F%3E%3Cpath%20d%3D%22m12%205c-.414%200-.75-.336-.75-.75v-3.5c0-.414.336-.75.75-.75s.75.336.75.75v3.5c0%20.414-.336.75-.75.75z%22%2F%3E%3Cpath%20d%3D%22m23.25%2012.75h-3.5c-.414%200-.75-.336-.75-.75s.336-.75.75-.75h3.5c.414%200%20.75.336.75.75s-.336.75-.75.75z%22%2F%3E%3Cpath%20d%3D%22m12%2024c-.414%200-.75-.336-.75-.75v-3.5c0-.414.336-.75.75-.75s.75.336.75.75v3.5c0%20.414-.336.75-.75.75z%22%2F%3E%3Cpath%20d%3D%22m4.25%2012.75h-3.5c-.414%200-.75-.336-.75-.75s.336-.75.75-.75h3.5c.414%200%20.75.336.75.75s-.336.75-.75.75z%22%2F%3E%3Cpath%20d%3D%22m12%2015c-1.654%200-3-1.346-3-3s1.346-3%203-3%203%201.346%203%203-1.346%203-3%203zm0-4.5c-.827%200-1.5.673-1.5%201.5s.673%201.5%201.5%201.5%201.5-.673%201.5-1.5-.673-1.5-1.5-1.5z%22%2F%3E%3C%2Fsvg%3E";

let AnnotationLens = class AnnotationLens extends LitElement {
    constructor() {
        super();
        this.resizeCanvas = () => {
            this.imageBoundingBox = getImageBoundingBox(this.container, this.imageObject);
            this.resizeStage();
            const { width, height, scale } = this.imageBoundingBox;
            this.imageShape.width(width / scale);
            this.imageShape.height(height / scale);
            this.onPointerPositionChange();
            this.imageLayer.batchDraw();
            this.loadShapes();
        };
        this.onPointerPositionChange = () => {
            if (!this.imageBoundingBox) {
                return;
            }
            handleLensZoom(this.stage, this.imageBoundingBox, this.pointerPosition, this.zoomLevel);
        };
        this.resizeStage = () => {
            const { x, y, scale } = this.imageBoundingBox;
            this.stage.scale({
                x: scale,
                y: scale,
            });
            this.stage.position({ x, y });
            this.stage.width(this.container.clientWidth);
            this.stage.height(this.container.clientHeight);
        };
        this.loadImage = () => {
            this.imageObject.onload = () => {
                this.imageShape.image(this.imageObject);
                this.imageLayer.batchDraw();
                this.resizeCanvas();
            };
            if (this.orientation) {
                rotateImage(this.image, this.orientation).then((image) => {
                    this.imageObject.src = image;
                });
            }
            else {
                this.imageObject.src = this.image;
            }
        };
        this.loadShapes = () => {
            if (!this.imageBoundingBox) {
                return;
            }
            const polygons = mapShapesToPolygons(this.stage, this.shapes, this.imageBoundingBox, {}, this.options);
            if (polygons.length) {
                this.shapesLayer.add(...polygons);
            }
            this.shapesLayer.batchDraw();
        };
        this.stage = null;
        this._image = '';
        this._shapes = [];
        this._zoomLevel = 2;
        this._orientation = 0;
        this._options = DEFAULT_OPTIONS;
        this._pointerPosition = { x: 0, y: 0 };
        this.imageBoundingBox = null;
        this.polygons = [];
        this.imageLayer = new Konva.Layer({ id: KONVA_REFS.imageLayer });
        this.shapesLayer = new Konva.Layer({ id: KONVA_REFS.shapesLayer });
        this.imageObject = new Image();
        this.imageShape = new Konva.Image({
            name: KONVA_REFS.imageShape,
            image: this.imageObject,
        });
    }
    get shapes() {
        return this._shapes;
    }
    set shapes(value) {
        this._shapes = value;
        this.loadShapes();
    }
    get image() {
        return this._image;
    }
    set image(value) {
        this._image = value;
        this.loadImage();
    }
    get orientation() {
        return this._orientation;
    }
    set orientation(value) {
        this._orientation = value || 0;
        this.loadImage();
    }
    get zoomLevel() {
        return this._zoomLevel;
    }
    set zoomLevel(value) {
        this._zoomLevel = value;
        this.onPointerPositionChange();
    }
    get pointerPosition() {
        return this._pointerPosition;
    }
    set pointerPosition(value) {
        this._pointerPosition = value || { x: 0, y: 0 };
        this.onPointerPositionChange();
    }
    get options() {
        return this._options;
    }
    set options(value) {
        this._options = Object.assign(Object.assign({}, this._options), value);
    }
    firstUpdated() {
        this.container = this.shadowRoot.getElementById('container');
        this.stage = new Konva.Stage({
            // @ts-ignore
            container: this.container,
            width: this.container.clientWidth,
            height: this.container.clientHeight,
        });
        this.imageLayer.add(this.imageShape);
        // @ts-ignore
        this.stage.add(this.imageLayer, this.shapesLayer);
    }
    render() {
        return html `${LensStyle(this.options.backgroundColor)}
      <div class="wrapper">
        <img class="icon" src=${targetIcon} />
        <div id="container"></div>
      </div>`;
    }
};
__decorate([
    property({ type: Array })
], AnnotationLens.prototype, "shapes", null);
__decorate([
    property({ type: String })
], AnnotationLens.prototype, "image", null);
__decorate([
    property({ type: Number })
], AnnotationLens.prototype, "orientation", null);
__decorate([
    property({ type: Number, attribute: 'zoom-level' })
], AnnotationLens.prototype, "zoomLevel", null);
__decorate([
    property({ type: Object, attribute: 'pointer-position' })
], AnnotationLens.prototype, "pointerPosition", null);
__decorate([
    property({ type: Object })
], AnnotationLens.prototype, "options", null);
__decorate([
    internalProperty()
], AnnotationLens.prototype, "imageBoundingBox", void 0);
__decorate([
    internalProperty()
], AnnotationLens.prototype, "polygons", void 0);
AnnotationLens = __decorate([
    customElement('annotation-lens')
], AnnotationLens);

export { getImagesFromPDF };
//# sourceMappingURL=index.js.map
